API
===

.. automodule:: sftpretty
   :members:


SecurityOptions
---------------
A simple object returned with available security preferences.

See `Security Options <https://docs.paramiko.org/en/latest/api/transport.html?highlight=ciphers#paramiko.transport.SecurityOptions>`_ for details.


SFTPAttributes
--------------
Representation of the attributes of a file or proxied file.

See `SFTPAttributes <https://docs.paramiko.org/en/latest/api/sftp.html?highlight=sftpattributes#paramiko.sftp_attr.SFTPAttributes>`_ for details.


SFTPFile
--------
Proxy object for a file on the remote server.

See `SFTPFile <https://docs.paramiko.org/en/latest/api/sftp.html?highlight=paramiko.sftp_file.sftpfile#paramiko.sftp_file.SFTPFile>`_ for details.
